@@ -1,5 +1,5 @@
 from .core import (
-    init_db,
+    init,
     connection,
     transaction,
     with_connection,
