@@ -5,7 +5,7 @@ import functools
 from .log_support import logger
 from .engine import Engine, Driver
 from .init_import import import_driver
-from .sql_support import limit_one_sql_args
+from .sql_support import limit_one_sql
 from .log_support import do_sql_log, do_save_log
 from .constant import PARAM_DRIVER, PARAM_DEBUG, PARAM_POOL_SIZE, MODULE, PARAM_SHOW_SQL
 from .support import DBCtx, ConnectionCtx, TransactionCtx, try_commit, DBError, DB_LOCK, Dict, MultiColumnsError
@@ -15,16 +15,16 @@ _POOLED = False
 _SHOW_SQL = False
 
 
-def init_db(*args, **kwargs) -> Engine:
+def init(*args, **kwargs) -> Engine:
     """
     Compliant with the Python DB API 2.0 (PEP-249).
 
     from executor
-    executor.init_db('test.db', driver='sqlite3', debug=True)
+    executor.init('test.db', driver='sqlite3', debug=True)
     or
-    executor.init_db("postgres://user:password@127.0.0.1:5432/testdb", driver='psycopg2', pool_size=5, debug=True)
+    executor.init("postgres://user:password@127.0.0.1:5432/testdb", driver='psycopg2', pool_size=5, debug=True)
     or
-    executor.init_db(user='root', password='xxx', host='127.0.0.1', port=3306, database='testdb', driver='pymysql', pool_size=5, debug=True)
+    executor.init(user='root', password='xxx', host='127.0.0.1', port=3306, database='testdb', driver='pymysql', pool_size=5, debug=True)
 
     Addition parameters:
     :param driver=None: str|Driver, import driver, 'import pymysql'
@@ -265,7 +265,7 @@ def do_select_one(sql: str, *args):
     global _SHOW_SQL
     cursor = None
 
-    sql, args = limit_one_sql_args(sql, *args)
+    sql = limit_one_sql(sql)
 
     if _SHOW_SQL:
         do_sql_log(MODULE, 'do_select_one', sql, *args)
