@@ -1,5 +1,3 @@
-from .constant import LIMIT_1
-
 
 def require_limit(sql: str):
     lower_sql = sql.lower()
@@ -11,7 +9,7 @@ def require_limit(sql: str):
     return False
 
 
-def limit_one_sql_args(sql: str, *args):
+def limit_one_sql(sql: str):
     if require_limit(sql):
-        return '{} LIMIT ?'.format(sql), [*args, LIMIT_1]
-    return sql, args
+        return '{} LIMIT 1'.format(sql)
+    return sql
